@@ -115,7 +115,6 @@ impl Client {
 
 	pub fn post(&self, path: impl AsRef<str>) -> reqwest::RequestBuilder {
 		let url = self.build_url(path);
-		//println!("{}", url);
 		let mut request = self.http.post(&url);
 		request = match &self.auth {
 			Some(auth) => request.basic_auth(&auth.0, Some(&auth.1)),
@@ -188,7 +187,16 @@ impl Client {
 	}
 
 	pub async fn add_torrent_from_link(&mut self, url: impl ToString) -> Result<AddTorrentResponse, Error> {
-		let response: Response<AddTorrentResponse> = self.rpc("torrent-add", 8, AddTorrent{filename: url.to_string()}).await?.error_for_status()?.json().await?;
+		let response = self.rpc("torrent-add", 8, AddTorrent{filename: Some(url.to_string()), metainfo: None}).await?.error_for_status()?.text().await?;
+		let response: Response<AddTorrentResponse> = serde_json::from_str(&response)?;
+		Ok(response.arguments)
+	}
+
+	pub async fn add_torrent(&mut self, url: impl ToString) -> Result<AddTorrentResponse, Error> {
+		let response = reqwest::get(&url.to_string()).await?.bytes().await?;
+		let torrent_data = base64::encode(&response);
+		let response = self.rpc("torrent-add", 8, AddTorrent{filename: None, metainfo: Some(torrent_data)}).await?.error_for_status()?.text().await?;
+		let response: Response<AddTorrentResponse> = serde_json::from_str(&response)?;
 		Ok(response.arguments)
 	}
 
